<?php
/**
* Main page generator
* 
* This page generates all of the pages in the site.
* It takes care of authentication and all that stuff
* and then includes the actual page that the user
* requested
*
* @author Stewart Smith
*/

include 'config.inc.php';

/**
* Database access functions
*
* @see database
*/
require_once 'backend/database.inc.php';

/**
* Include Authentication code
*
* @see authentication.inc.php
*/
include 'backend/authentication.inc.php';

/**
* Syslog functionality
*
* @see syslog
*/
// include 'backend/syslog.inc.php';

// Start the session
session_start();

if(login($_SESSION['user'],$_SESSION['password']))
     $logged_in = 1;
     
if($_GET['page']=='confirm_membership')
     $_POST['function']='confirm_membership';

switch($_POST['function']) {
 case 'main':
   $_SESSION['user'] = $_POST['user'];
   $_SESSION['password'] = $_POST['password'];

   if(login($_SESSION['user'],$_SESSION['password']))
     $logged_in = 1;
   break;
   
 case 'logout':
   $logged_in = 0;
   $_SESSION['user']='';
   $_SESSION['password']='';
   break;
   
 case 'confirm_membership':
   include 'backend/functions/confirm_membership.inc';
   break;

 case 'signup_validate':
   /*
    * Fallthrough - we validate stuff in the signup page code
    */
   break;

 case 'signup':
   include 'backend/functions/signup.inc';
   break;

 case 'approve_members':
   include 'backend/functions/approve_members.inc';
   break;

 case '':
   break;
 default:
   echo 'Unknown Function! '.$_POST['function'];
   my_syslog(LOG_WARNING,"Unknown function submitted - ".$_POST['function']);
   break;
}

/* if after performing the function we still don't have a page
   to view, then we set one
*/
if(!$page)
{
  $page = $HTTP_GET_VARS['page'];
  if($page=='') $page = 'index';
}

if($logged_in)
{
  if(is_file('authenticated/'.$page.'.inc.php'))
    {
      // we're logged in, and authenticated page exists... so...
      $page_inc = 'authenticated/'.$page.".inc.php";
    }
  else
    {
      if(is_file('unauthenticated/'.$page.'.inc.php'))
	{
	  // try the unauthenticated page, as there isn't an auth version
	  $page_inc = 'unauthenticated/'.$page.'.inc.php';
	}
      else
	{
	  // the file doesn't exist, and we're authenticated
	  $page = 'index';
	  $page_inc = $page.'.inc.php';
	}
    }
}
else
{
  if(is_file('unauthenticated/'.$page.'.inc.php'))
    {
      // we're not authenticated, and not logged in, but the page exists.
      $page_inc = 'unauthenticated/'.$page.'.inc.php';
    }
  else
    {
      if(is_file($page.'.inc.php'))
	{
	  // The inc file is in the current dir
	  $page_inc = $page.'.inc.php';
	}
      else
	{
	  // default back to index
	  $page = 'index';
	  $page_inc = 'index.inc.php';
	}
    }
}

function headers($title)
{
  header("Content-Type: text/html; charset=utf-8");
  header("X-Pants: off");
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en">
 <head>
  <title><?=$title?></title>
  <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
  <link rel="stylesheet" type="text/css" href="global.css" />
 </head>
<body>

<?php
}

include $page_inc;

?>
</body>
</html>
